@@ -34,7 +34,7 @@
 #define _GLIBCXX_RELEASE 13
 
 // The datestamp of the C++ library in compressed ISO date format.
-#define __GLIBCXX__ 20230902
+#define __GLIBCXX__ 20240426
 
 // Macros for various attributes.
 //   _GLIBCXX_PURE
@@ -1090,7 +1090,7 @@ namespace __gnu_cxx
 #define _GLIBCXX_HAVE_LDEXPL 1
 
 /* Define to 1 if you have the <libintl.h> header file. */
-/* #undef _GLIBCXX_HAVE_LIBINTL_H */
+#define _GLIBCXX_HAVE_LIBINTL_H 1
 
 /* Only used in build directory testsuite_hooks.h. */
 #define _GLIBCXX_HAVE_LIMIT_AS 1
@@ -1377,7 +1377,7 @@ namespace __gnu_cxx
 #define _GLIBCXX_HAVE_TRUNCATE 1
 
 /* Define to 1 if you have the <uchar.h> header file. */
-/* #undef _GLIBCXX_HAVE_UCHAR_H */
+#define _GLIBCXX_HAVE_UCHAR_H 1
 
 /* Define to 1 if you have the <unistd.h> header file. */
 #define _GLIBCXX_HAVE_UNISTD_H 1
@@ -1775,7 +1775,7 @@ namespace __gnu_cxx
 
 /* Define if C11 functions in <uchar.h> should be imported into namespace std
    in <cuchar>. */
-/* #undef _GLIBCXX_USE_C11_UCHAR_CXX11 */
+#define _GLIBCXX_USE_C11_UCHAR_CXX11 1
 
 /* Define if C99 functions or macros from <wchar.h>, <math.h>, <complex.h>,
    <stdio.h>, and <stdlib.h> can be used or exposed. */
@@ -1810,6 +1810,12 @@ namespace __gnu_cxx
    namespace std::tr1. */
 #define _GLIBCXX_USE_C99_STDINT_TR1 1
 
+/* Define if usable chdir is available in <unistd.h>. */
+#define _GLIBCXX_USE_CHDIR 1
+
+/* Define if usable chmod is available in <sys/stat.h>. */
+#define _GLIBCXX_USE_CHMOD 1
+
 /* Defined if clock_gettime syscall has monotonic and realtime clock support.
    */
 /* #undef _GLIBCXX_USE_CLOCK_GETTIME_SYSCALL */
@@ -1837,6 +1843,9 @@ namespace __gnu_cxx
 /* Define if fseeko and ftello are available. */
 #define _GLIBCXX_USE_FSEEKO_FTELLO 1
 
+/* Define if usable getcwd is available in <unistd.h>. */
+#define _GLIBCXX_USE_GETCWD 1
+
 /* Defined if gettimeofday is available. */
 #define _GLIBCXX_USE_GETTIMEOFDAY 1
 
@@ -1855,6 +1864,9 @@ namespace __gnu_cxx
 /* Define if lstat is available in <sys/stat.h>. */
 #define _GLIBCXX_USE_LSTAT 1
 
+/* Define if usable mkdir is available in <sys/stat.h>. */
+#define _GLIBCXX_USE_MKDIR 1
+
 /* Defined if nanosleep is available. */
 #define _GLIBCXX_USE_NANOSLEEP 1
 
@@ -1910,11 +1922,11 @@ namespace __gnu_cxx
 
 /* Define if c8rtomb and mbrtoc8 functions in <uchar.h> should be imported
    into namespace std in <cuchar> for C++20. */
-/* #undef _GLIBCXX_USE_UCHAR_C8RTOMB_MBRTOC8_CXX20 */
+#define _GLIBCXX_USE_UCHAR_C8RTOMB_MBRTOC8_CXX20 1
 
 /* Define if c8rtomb and mbrtoc8 functions in <uchar.h> should be imported
    into namespace std in <cuchar> for -fchar8_t. */
-/* #undef _GLIBCXX_USE_UCHAR_C8RTOMB_MBRTOC8_FCHAR8_T */
+#define _GLIBCXX_USE_UCHAR_C8RTOMB_MBRTOC8_FCHAR8_T 1
 
 /* Define if utime is available in <utime.h>. */
 #define _GLIBCXX_USE_UTIME 1
